package com.shzg.project.unique.service;

import java.util.List;
import com.shzg.project.unique.domain.WornUniqueCodeMaterial;

/**
 * 唯一码物料信息Service接口
 * 
 * @author shzg
 * @date 2026-03-17
 */
public interface IWornUniqueCodeMaterialService 
{
    /**
     * 查询唯一码物料信息
     * 
     * @param id 唯一码物料信息主键
     * @return 唯一码物料信息
     */
    public WornUniqueCodeMaterial selectWornUniqueCodeMaterialById(Long id);

    /**
     * 查询唯一码物料信息列表
     * 
     * @param wornUniqueCodeMaterial 唯一码物料信息
     * @return 唯一码物料信息集合
     */
    public List<WornUniqueCodeMaterial> selectWornUniqueCodeMaterialList(WornUniqueCodeMaterial wornUniqueCodeMaterial);

    /**
     * 新增唯一码物料信息
     * 
     * @param wornUniqueCodeMaterial 唯一码物料信息
     * @return 结果
     */
    public int insertWornUniqueCodeMaterial(WornUniqueCodeMaterial wornUniqueCodeMaterial);

    /**
     * 修改唯一码物料信息
     * 
     * @param wornUniqueCodeMaterial 唯一码物料信息
     * @return 结果
     */
    public int updateWornUniqueCodeMaterial(WornUniqueCodeMaterial wornUniqueCodeMaterial);

    /**
     * 批量删除唯一码物料信息
     * 
     * @param ids 需要删除的唯一码物料信息主键集合
     * @return 结果
     */
    public int deleteWornUniqueCodeMaterialByIds(Long[] ids);

    /**
     * 删除唯一码物料信息信息
     * 
     * @param id 唯一码物料信息主键
     * @return 结果
     */
    public int deleteWornUniqueCodeMaterialById(Long id);
}
